@@ -266,8 +266,10 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 
 			if (to_kind == AS_MARKUP_KIND_MARKDOWN) {
 				g_auto(GStrv) spl = as_markup_strsplit_words (clean_text, 100);
-				for (guint i = 0; spl[i] != NULL; i++)
-					g_string_append (str, spl[i]);
+				if (spl != NULL) {
+					for (guint i = 0; spl[i] != NULL; i++)
+						g_string_append (str, spl[i]);
+				}
 			} else {
 				g_string_append_printf (str, "%s\n", clean_text);
 			}
@@ -310,9 +312,11 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 
 					/* break to 100 chars, leaving room for the dot/indent */
 					spl = as_markup_strsplit_words (clean_item, 100 - 4);
-					g_string_append_printf (str, " %s %s", item_c, spl[0]);
-					for (guint i = 1; spl[i] != NULL; i++)
-						g_string_append_printf (str, "   %s", spl[i]);
+					if (spl != NULL) {
+						g_string_append_printf (str, " %s %s", item_c, spl[0]);
+						for (guint i = 1; spl[i] != NULL; i++)
+							g_string_append_printf (str, "   %s", spl[i]);
+					}
 				} else {
 					/* only <li> is valid in lists */
 					ret = FALSE;
@@ -404,6 +408,36 @@ as_iso8601_to_datetime (const gchar *iso_date)
 	return g_date_time_new_utc (dmy[0], dmy[1], dmy[2], 0, 0, 0);
 }
 
+/**
+ * as_str_verify_integer:
+ * @str: The string to test.
+ * @min_value: Minimal value to be considered valid, e.g. %G_MININT64
+ * @max_value: Maximum value to be considered valie, e.g. %G_MAXINT64
+ *
+ * Verify that a string is an integer in the given range.
+ * Unlike strtoll(), this function will only pass if the whole string
+ * consists of numbers, and will not succeed if the string has a text suffix.
+ *
+ * Returns: %TRUE if verified correctly according to the set conditions, %FALSE otherwise.
+ */
+gboolean
+as_str_verify_integer (const gchar *str, gint64 min_value, gint64 max_value)
+{
+	gchar *endptr;
+	gint64 res;
+	g_return_val_if_fail (min_value < max_value, FALSE);
+
+	if (as_is_empty (str))
+		return FALSE;
+
+	res = g_ascii_strtoll (str, &endptr, 10);
+	/* check if we used the whole string for conversion */
+	if (endptr[0] != '\0')
+		return FALSE;
+
+	return res >= min_value && res <= max_value;
+}
+
 /**
  * as_utils_delete_dir_recursive:
  * @dirname: Directory to remove
@@ -938,10 +972,8 @@ as_utils_locale_to_language (const gchar *locale)
 const gchar*
 as_ptr_array_find_string (GPtrArray *array, const gchar *value)
 {
-	const gchar *tmp;
-	guint i;
-	for (i = 0; i < array->len; i++) {
-		tmp = g_ptr_array_index (array, i);
+	for (guint i = 0; i < array->len; i++) {
+		const gchar *tmp = g_ptr_array_index (array, i);
 		if (g_strcmp0 (tmp, value) == 0)
 			return tmp;
 	}
